@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import List, Tuple
+from typing import List, Tuple, Set, Any
 import re
 import numpy as np
 from rdkit import Chem
@@ -13,7 +13,8 @@ class Molecule:
     """
     Instance of molecule using RDKit `Mol` class.
 
-    It's instantiate by providing SMILES but it's also possible to use `from_rdkit()` class method
+    It's instantiate by providing SMILES but it's
+    also possible to use `from_rdkit()` class method
     to instantiate from RDKit `Mol` instance.
 
     !!! example
@@ -49,7 +50,7 @@ class Molecule:
         """
         self._set_aromaticity_model(aromaticity)
         self._set_rdkit(smiles, preserve_H=preserve_H)
-        self._smiles = Chem.MolToSmiles(self.rdkit)
+        self._smiles: str = Chem.MolToSmiles(self.rdkit)
 
     @property
     def smiles(self) -> str:
@@ -58,24 +59,27 @@ class Molecule:
 
     @property
     def rdkit(self) -> Chem.Mol:
-        """`rdkit.Chem.Mol` instance of the molecule. Use it to directly apply RDKit methods"""
+        """
+        `rdkit.Chem.Mol` instance of the molecule.
+        Use it to directly apply RDKit methods
+        """
         return self._rdkit.__copy__()
 
     @property
-    def smiles_kekulized(self):
+    def smiles_kekulized(self) -> str:
         """Kekulized SMILES of the molecule"""
-        return Chem.MolToSmiles(self._kekulize_rdkit())
+        return Chem.MolToSmiles(self._kekulize_rdkit())  # type: ignore
 
     @property
-    def mass(self):
-        return Descriptors.MolWt(self.rdkit)
+    def mass(self) -> float:
+        return Descriptors.MolWt(self.rdkit)  # type: ignore
 
-    def _kekulize_rdkit(self):
+    def _kekulize_rdkit(self) -> Chem.Mol:
         mol = self.rdkit
         Chem.Kekulize(mol, clearAromaticFlags=True)
         return mol
 
-    def __eq__(self, other):
+    def __eq__(self: Molecule, other: object) -> bool:
         """
         Comparaison betwwen two Molecule instances is done
         by comparing cannonical SMILES (`.smiles` property)
@@ -101,22 +105,22 @@ class Molecule:
         return cls(smiles)
 
     @staticmethod
-    def resolve_charge(rdkit):
-        map_charge = re.findall(r"\[#\d+\&(\++):(\d+)]", Chem.MolToSmarts(rdkit))
-        map_charge = {int(map_num): len(charge) for charge, map_num in map_charge}
+    def resolve_charge(rdkit: Chem.Mol) -> Chem.Mol:
+        findall = re.findall(r"\[#\d+\&(\++):(\d+)]", Chem.MolToSmarts(rdkit))
+        map_charge = {int(map_num): len(charge) for charge, map_num in findall}
         for atom in rdkit.GetAtoms():
             charge = map_charge.get(atom.GetAtomMapNum())
             if charge:
                 atom.SetFormalCharge(charge)
         return rdkit
 
-    def _set_aromaticity_model(self, aromaticity):
+    def _set_aromaticity_model(self, aromaticity: str) -> None:
         self._AROMATICITY_MODEL = getattr(
             Chem.rdmolops.AromaticityModel,
             "AROMATICITY_{}".format(aromaticity.upper()),
         )
 
-    def _set_rdkit(self, smiles, preserve_H):
+    def _set_rdkit(self, smiles: str, preserve_H: bool) -> None:
         if preserve_H:
             mol = self._mol_from_smiles_preserve_H(smiles)
         else:
@@ -126,7 +130,7 @@ class Molecule:
         self._rdkit = mol
 
     @staticmethod
-    def _mol_from_smiles_preserve_H(smiles):
+    def _mol_from_smiles_preserve_H(smiles: str) -> Chem.Mol:
         mol = Chem.MolFromSmiles(smiles, sanitize=False)
         sanitize_params = [
             # "ADJUSTHS",
@@ -152,7 +156,7 @@ class Molecule:
         Chem.SanitizeMol(mol, sanitize_param)
         return mol
 
-    def _repr_svg_(self):
+    def _repr_svg_(self) -> Any:
         """
         Modified to highlight bonds, from :
         https://github.com/rdkit/rdkit/blob/bc4d5478478542045a0f89e28a5da8b6d1f0e5d0/rdkit/Chem/Draw/IPythonConsole.py#L112
@@ -168,7 +172,7 @@ class Molecule:
             highlightBonds=getattr(mol, "__sssBonds", []),
         )
 
-    def get_substructure_match(self, smarts: str) -> Tuple[tuple]:
+    def get_substructure_match(self, smarts: str) -> Tuple[Tuple[int]]:
         """
         Apply RDKit `GetSubstructMatches` method.
 
@@ -183,7 +187,7 @@ class Molecule:
         """
         substructure = Chem.MolFromSmarts(smarts)
         mol = self.rdkit
-        matches = mol.GetSubstructMatches(substructure)
+        matches: Tuple[Tuple[int]] = mol.GetSubstructMatches(substructure)
         highlight_atoms = getattr(mol, "__sssAtoms", [])
         highlight_bonds = [
             bond.GetIdx()
@@ -194,14 +198,14 @@ class Molecule:
         setattr(self._rdkit, "__sssBonds", highlight_bonds)
         return matches
 
-    def _is_highlight_bond(self, bond, highlight_atoms):
+    def _is_highlight_bond(self, bond: Chem.Bond, highlight_atoms: List[int]) -> bool:
         return set(self._get_bond_atoms(bond)).issubset(set(highlight_atoms))
 
     @staticmethod
-    def _get_bond_atoms(bond):
+    def _get_bond_atoms(bond: Chem.Bond) -> List[int]:
         return [bond.GetBeginAtomIdx(), bond.GetEndAtomIdx()]
 
-    def highlight_aromatics(self):
+    def highlight_aromatics(self) -> Molecule:
         """Highlight aromatics rings"""
         mol = self.rdkit
         ring_info = mol.GetRingInfo()
@@ -217,16 +221,17 @@ class Molecule:
         setattr(self._rdkit, "__sssBonds", aromatic_bonds)
         return self
 
-    def get_atoms(self):
+    def get_atoms(self) -> Chem._ROAtomSeq:
         """Yield every atom in the molecule"""
         return self.rdkit.GetAtoms()
 
-    def get_ring_systems(self, includeSpiro: bool = False) -> List[set]:
+    def get_ring_systems(self, includeSpiro: bool = False) -> List[Set[int]]:
         """
         Get all ring systems.
 
         !!! note
-            From [RDKit Cookbook](https://www.rdkit.org/docs/Cookbook.html#count-ring-systems)
+            From [RDKit Cookbook]\
+(https://www.rdkit.org/docs/Cookbook.html#count-ring-systems)
 
         Returns:
             List of set if atom id for each ring systems
@@ -234,9 +239,9 @@ class Molecule:
         return self._get_ring_systems(self.rdkit, includeSpiro=includeSpiro)
 
     @staticmethod
-    def _get_ring_systems(mol, includeSpiro: bool = False):
+    def _get_ring_systems(mol: Chem.Mol, includeSpiro: bool = False) -> List[Set[int]]:
         ring_info = mol.GetRingInfo()
-        systems = []
+        systems: List[Set[int]] = []
         for ring in ring_info.AtomRings():
             ringAts = set(ring)
             nSystems = []
